@@ -227,6 +227,7 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
         :var dataframe: Variable outputted to event function that is a buffered dataframe
         :var row_start: Row number for first row of data
         :var row_end: Row number for last row of data
+        :var kwargs: kwargs from sql_execute command
         """
 
         def registerhandler(handler):
@@ -236,7 +237,7 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
         return registerhandler
 
     def sql_execute(self, query_str, execute=False, queue_cursor=False, new_engine=False, csv_path=None,
-                    csv_replace=False, delimiter=',', quotechar='"', quoting=QUOTE_ALL):
+                    csv_replace=False, delimiter=',', quotechar='"', quoting=QUOTE_ALL, **kwargs):
         """
         Execute or Query SQL query statement. This command can be multi-threaded in a cursor queue
 
@@ -249,6 +250,7 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
         :param delimiter: Data seperator to delimit columns
         :param quotechar: Quote Character to wrap values with
         :param quoting: csv quote mode
+        :param kwargs: Kwarg values
 
         :return: Returns Cursor class if queue_cursor is set to False
         """
@@ -262,14 +264,14 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
 
         if new_engine:
             return self.__execute_sql(engine, spid, keep_engine_alive, query_str, execute, queue_cursor, csv_path,
-                               csv_replace, delimiter, quotechar, quoting)
+                               csv_replace, delimiter, quotechar, quoting, **kwargs)
         else:
             with self.__engine_lock:
                 return self.__execute_sql(engine, spid, keep_engine_alive, query_str, execute, queue_cursor, csv_path,
-                                   csv_replace, delimiter, quotechar, quoting)
+                                   csv_replace, delimiter, quotechar, quoting, **kwargs)
 
     def __execute_sql(self, engine, spid, keep_engine_alive, query_str, execute=False, queue_cursor=False,
-                      csv_path=None, csv_replace=False, delimiter=',', quotechar='"', quoting=QUOTE_ALL):
+                      csv_path=None, csv_replace=False, delimiter=',', quotechar='"', quoting=QUOTE_ALL, **kwargs):
         from ..sql.cursor import SQLCursor
 
         if queue_cursor:
@@ -292,7 +294,7 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
                     cursor.start()
                     cursor.execute(query_str=query_str, execute=execute, handler=handler, buffer=buffer,
                                    csv_path=csv_path, csv_replace=csv_replace, delimiter=delimiter,
-                                   quotechar=quotechar, quoting=quoting)
+                                   quotechar=quotechar, quoting=quoting, **kwargs)
                     cursor.join()
                 except Exception as e:
                     cursor.close()
@@ -306,7 +308,7 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
             try:
                 cursor.start()
                 cursor.execute(query_str=query_str, execute=execute, csv_path=csv_path, csv_replace=csv_replace,
-                               delimiter=delimiter, quotechar=quotechar, quoting=quoting)
+                               delimiter=delimiter, quotechar=quotechar, quoting=quoting, **kwargs)
                 cursor.join()
             except:
                 cursor.close()
